# <img src="https://uploads-ssl.webflow.com/5ea5d3315186cf5ec60c3ee4/5edf1c94ce4c859f2b188094_logo.svg" alt="Pip.Services Logo" width="200"> <br/> MongoDB components for Python Changelog

## <a name="3.0.5"></a> 3.0.5 (2021-02-19)

### Features
* Added defineSchema method that shall be overriden in child classes
* Added clearSchema method
* Added creating local connection in MongoDb Persistence

## <a name="3.0.1-3.0.4"></a> 3.0.1-3.0.4 (2020-03-01-2020-08-02)

### Changes
* moved methods to MemoryPersistence

### Features
* added DefaultMongoDbFactory
* added MongoDbConnetction

### Bug Fixes
* fixed MongoDbPersistence


## <a name="3.0.0"></a> 3.0.0 (2018-10-30)

Initial public release

### Features
- **Connect** - MongoDb connection resolver
- **Persistence** - MongoDb persistence